# Laskea

Calculate (Finnish: laskea) some parts.

[License: MIT](https://git.sr.ht/~sthagen/laskea/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](third-party/README.md).

[![version](https://img.shields.io/pypi/v/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![downloads](https://img.shields.io/pypi/dm/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![wheel](https://img.shields.io/pypi/wheel/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![supported-versions](https://img.shields.io/pypi/pyversions/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![supported-implementations](https://img.shields.io/pypi/implementation/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of laskea](https://todo.sr.ht/~sthagen/laskea).

## Primary Source repository

The primary source repository of [laskea is at sourcehut](https://git.sr.ht/~sthagen/laskea)
a collection of tools useful for software development.
